@@ -1,5 +1,6 @@
 #******************************************************************************
-#**** Copyright (C) 2009  John Schneiderman <JohnMS@member.fsf.org>        ****
+#**** Copyright (C) 2009, 2010                                             ****
+#****   John Schneiderman <JohnMS@member.fsf.org>                          ****
 #****                                                                      ****
 #**** This program is free software: you can redistribute it and/or modify ****
 #**** it under the terms of the GNU General Public License as published by ****
@@ -24,9 +25,14 @@ __all__ =   [   "kap.py",
                 "medialibrarythread.py",
                 "mediaparser.py",
                 "mediasong.py",
+                "mediasongdataobject.py",
+                "mediasongdroptarget.py",
                 "mplayerplayer.py",
+                "mplayersignal.py",
                 "playerbase.py",
+                "playercontroller.py",
                 "playerfactory.py",
+                "playersignal.py",
                 "playerthread.py",
                 "playerwindow.py",
                 "playlistwindow.py",
