@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 #******************************************************************************
-#**** Copyright (C) 2009  John Schneiderman <JohnMS@member.fsf.org>        ****
+#**** Copyright (C) 2009, 2010                                             ****
+#****   John Schneiderman <JohnMS@member.fsf.org>                          ****
 #****                                                                      ****
 #**** This program is free software: you can redistribute it and/or modify ****
 #**** it under the terms of the GNU General Public License as published by ****
@@ -19,39 +20,30 @@
 """
  IMPORTS
 """
-import playerbase as PlayerBase
-import playerthread as PlayerThread
+import playerbase as Base
+import playerthread as Thread
 import mediasong as MediaSong
+import mplayersignal as Signaller
 
 
-class MPlayerPlayer(PlayerBase.PlayerBase):
+class MPlayerPlayer(Base.PlayerBase):
     """ A Non-Blocking player for MPlayer """
 
     # The PlayerThread that runs MPlayer.
     __mplayer = None
 
-    def __init__(self, volumeLevel, additionalArguments=""):
+    def __init__(self, volumeLevel=100, additionalArguments=""):
         """ Default constructor
 
          Initialises and starts the player thread for using MPlayer.
-         int volumeLevel: is the percentage level for play music.
+         int volumeLevel: is the percentage level for playing music.
          string additionalArguments: are any additional arguments to pass along
-           to MPlayer when playing a song.
+           to MPlayer when playing a song in addtion to the standard arguments.
         """
-        PlayerBase.__init__("MPlayer")
-        self.__mplayer = PlayerThread.PlayerThread("mplayer", \
-            "-slave -quiet " + additionalArguments, volumeLevel)
-        # Setup the signals
-        self.__mplayer.signalPlay = ""
-        self.__mplayer.signalPause = "pause"
-        self.__mplayer.signalUnpause = "pause"
-        self.__mplayer.signalStop = "quit"
-        self.__mplayer.signalVolume = "volume"
-        self.__mplayer.signalTotalTime = "get_time_length"
-        self.__mplayer.signalPositionTime = "get_time_pos"
-        self.__mplayer.signalSetPositionTime = "seek"
-        self.__mplayer.signalQuit = "quit"
-        self.__mplayer.signalFullScreen = "vo_fullscreen 1"
+        print "MPlayerPlayer.__init__(self, volumeLevel, additionalArguments)"
+        Base.PlayerBase.__init__(self, "MPlayer")
+        self.__mplayer = Thread.PlayerThread( \
+            Signaller.MPlayerSignal(volumeLevel, additionalArguments))
 
     def __del__(self):
         """ Ensure the player thread has stopped. """
@@ -63,6 +55,7 @@ class MPlayerPlayer(PlayerBase.PlayerBase):
 
     def quitRunning(self):
         """ Signal MPlayer to quit running. """
+        print "MPlayerPlayer.quitRunning(self)", self
         self.__mplayer.quitRunning()
 
     def isSongEnded(self):
@@ -82,7 +75,7 @@ class MPlayerPlayer(PlayerBase.PlayerBase):
            if one of the pre-conditions for starting to play is not met at the
            time of sending the signal.
         """
-        print "MPlayerPlayer.playSong(self, song, volume)", song, volume
+        print "MPlayerPlayer.playSong(self, song, volume)", self, song, volume
         if song.filePath is not None:
             successPlay = self.__mplayer.play(song.filePath, volume)
             if successPlay and song.blIsVideo:
