@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 #******************************************************************************
-#**** Copyright (C) 2009  John Schneiderman <JohnMS@member.fsf.org>        ****
+#**** Copyright (C) 2009, 2010                                             ****
+#****   John Schneiderman <JohnMS@member.fsf.org>                          ****
 #****                                                                      ****
 #**** This program is free software: you can redistribute it and/or modify ****
 #**** it under the terms of the GNU General Public License as published by ****
@@ -30,14 +31,14 @@ class PlayerFactory:
     """
 
     """
-     DJ PLAYER TYPES
+     MEDIA PLAYER TYPES
     """
-    __ID_MPLAYER = "MPlayer" # Supports MPlayer
+    __ID_MPLAYER = "MPlayer" # Supports mplayer
 
     """
      ATTRIBUTES
     """
-    # The DJ player type to use.
+    # The media player type to use.
     type_ = None
     # The media player created.
     player = None
