@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 #******************************************************************************
-#**** Copyright (C) 2009  John Schneiderman <JohnMS@member.fsf.org>        ****
+#**** Copyright (C) 2009, 2010                                             ****
+#****   John Schneiderman <JohnMS@member.fsf.org>                          ****
 #****                                                                      ****
 #**** This program is free software: you can redistribute it and/or modify ****
 #**** it under the terms of the GNU General Public License as published by ****
@@ -20,10 +21,10 @@
  IMPORTS
 """
 from threading import Thread, Lock, Condition
-from subprocess import Popen, PIPE
-import os
-import sys
 import Queue
+import playercontroller as Player
+import playersignal as Signaller
+import os
 
 
 class PlayerThread(Thread):
@@ -34,20 +35,8 @@ class PlayerThread(Thread):
     """
     # Player command queue
     __commandQueue = Queue.Queue()
-    # OS command to start the player.
-    __playerCommand = None
-    # Player arguments to pass along to the player upon invocation.
-    __PlayerCommandArguments = None
-    # File path to the currently playing song.
-    __songFilePath = None
-    # Subprocess containing the running player.
-    __ppnPlayer = None
-    # Volume level for playing the music
-    __volumeLevel = 0
-    # Total time in seconds of the currently playing song, in seconds.
-    __totalTime = 0.0
-    # Current position in the playing song, in seconds.
-    __positionTime = 0.0
+    __signal = None
+    __player = None
 
     """
      PLAYER STATES
@@ -64,14 +53,8 @@ class PlayerThread(Thread):
     __blIsSongEnded = False
 
     """
-     PLAYER THREAD LOCKS
+     THREAD LOCKS
     """
-    # Lock for writing to the standard input.
-    __lckWriteStandardInput = None
-    # Lock for reading from the standard out.
-    __lckReadStandardOut = None
-    # Lock for reading from the standard error.
-    __lckReadStandardError = None
     # Lock for accessing the command queue.
     __lckCommandQueue = None
     # Lock for running a command from the command queue.
@@ -79,30 +62,6 @@ class PlayerThread(Thread):
     # Condition for running a command from the command queue.
     __cndtnRunCommand = None
 
-    """
-     PLAYER SIGNALS
-    """
-    # OS command for playing a song in the player.
-    signalPlay = None
-    # Player command for pausing a song .
-    signalPause = None
-    # Player command for un-pausing a song.
-    signalUnpause = None
-    # Player command for stopping a song.
-    signalStop = None
-    # Player command for quitting a song.
-    signalQuit = None
-    # Player command for retrieving the volume level.
-    signalVolume = None
-    # Player command for retrieving the total time of the song.
-    signalTotalTime = None
-    # Player command for retrieving the playing position in the song.
-    signalPlayerPositionTime = None
-    # Player command for setting the playing position in the song.
-    signalSetPlayerPositionTime = None
-    # Player command for displaying the player in full screen.
-    signalFullScreen = None
-
     """
      SIGNAL COMMANDS
     """
@@ -131,24 +90,20 @@ class PlayerThread(Thread):
     # Indicates the player should display the song at full screen.
     __commandFullScreen = hex(0xB)
 
-    def __init__(self, playerCommand, arguments, volumeLevel):
+    def __init__(self, playerSignaller):
         """ Create and start the player thread.
 
-         Creates and starts the player thread. Note the signals to operate
-           the player must be set before attempting to use.
-         string playerCommand: is the OS command to start the player.
-         string arguments: is the command line arguments to pass to the player.
-         int volumeLevel: is the percentage volume level for the player.
+         Creates and starts the player thread and initialises all thread locks.
+         PlayerSignal playerSignaller: is the signal handeler for the media
+           player.
         """
-        Thread.__init__(self, name=playerCommand)
-        self.__playerCommand = playerCommand
-        self.__PlayerCommandArguments = arguments
-        self.__volumeLevel = volumeLevel
+        Thread.__init__(self, name=playerSignaller.name())
+        print "PlayerThread.__init__(self, playerSignaller)", self, \
+            playerSignaller
+        self.__signal = playerSignaller
+        self.__player = Player.PlayerController()
 
         # Create the locks and conditions
-        self.__lckWriteStandardInput = Lock()
-        self.__lckReadStandardOut = Lock()
-        self.__lckReadStandardError = Lock()
         self.__lckRunningCommand = Lock()
         self.__lckCommandQueue = Lock()
         self.__cndtnRunCommand = Condition(self.__lckRunningCommand)
@@ -165,148 +120,112 @@ class PlayerThread(Thread):
         while self.__blIsRunning:
             self.__cndtnRunCommand.acquire()
             command = self.__commandEmpty
+
             while self.__commandQueue.empty():
                 # Determine if the song has ended
-                if self.__blIsPlaying and (self.__totalTime > 0.0):
-                    if (self.__ppnPlayer.poll() is not None) or \
-                            (self.__positionTime == self.__totalTime):
+                if self.__blIsPlaying and (self.__signal.totalTime > 0.0):
+                    if self.__player.isPlayerReady() or \
+                            (self.__signal.positionTime == \
+                            self.__signal.totalTime):
                         self.__pushCommand(self.__commandSongEnd)
                 self.__cndtnRunCommand.wait()
+
             self.__lckCommandQueue.acquire()
             command = self.__commandQueue.get(True)
             self.__lckCommandQueue.release()
-            print "\nPlayer Thread Started Processing Command:", command
+            print " * Player Thread Processing Command:", command
 
             # Signal to quit the player
             if command == self.__commandQuitRunning:
-                print "Player Thread Running Signal Quit"
+                print " * Player Thread Running Signal Quit"
                 if self.__blIsPlaying or self.__blIsPaused:
                     self.__blIsPlaying = False
                     self.__blIsPaused = False
                     self.__blIsSongEnded = False
-                    self.__writeStandardInput('%s\n' % self.signalQuit)
-                    self.__ppnPlayer.wait()
+                    self.__signal.quit_(self.__player)
                 self.__lckCommandQueue.acquire()
                 while not self.__commandQueue.empty():
                     self.__commandQueue.get(True)
                 self.__lckCommandQueue.release()
                 self.__blIsRunning = False
-                print "Player Thread End Of Signal Quit"
+                print " * Player Thread End Of Signal Quit"
 
             # Signal to play the set song
-            # TODO use the play signal
             if command == self.__commandPlay:
                 if not self.__blIsPlaying and not self.__blIsPaused:
                     self.__blIsStarting = True
-                    signal = self.__playerCommand + " " + \
-                        self.__PlayerCommandArguments + self.__songFilePath
-                    print "Player Thread Running Signal Play: %s" % signal
-                    self.__ppnPlayer = Popen(signal, shell=True, \
-                        stdin=PIPE, stdout=PIPE, stderr=PIPE)
-                    if self.__ppnPlayer.poll() is not None:
-                        raise OSError("Failed to open media file!")
+                    print " * Player Thread Running Signal Play"
+                    self.__signal.play(self.__player)
                     self.__blIsPlaying = True
                     self.__blIsSongEnded = False
                     self.__blIsStarting = False
-                print "Player Thread End Of Signal Play"
+                print " * Player Thread End Of Signal Play"
 
             # Signal to display song at full screen
             if command == self.__commandFullScreen:
-                print "Player Thread Running Signal FullScreen: %s" % \
-                    self.signalFullScreen
-                self.__writeStandardInput('%s\n' % self.signalFullScreen)
-                print "Player Thread End Of Signal FullScreen"
+                print " * Player Thread Running Signal FullScreen"
+                self.__signal.fullScreen(self.__player)
+                print " * Player Thread End Of Signal FullScreen"
 
             # Signal to stop the song
             if command == self.__commandStop:
-                print "Player Thread Running Signal Stop: %s" % \
-                    self.signalStop
+                print " * Player Thread Running Signal Stop"
                 self.__blIsPlaying = False
                 self.__blIsPaused = False
-                self.__volumeLevel = 0
-                self.__totalTime = 0.0
-                self.__positionTime = 0.0
-                self.__writeStandardInput('%s\n' % self.signalStop)
-                print "Player Thread End Of Signal Stop"
+                self.__signal.stop(self.__player)
+                print " * Player Thread End Of Signal Stop"
 
             # Signal end of the song
             if command == self.__commandSongEnd:
-                print "Player Thread Running Signal Song End: %s" % \
-                    self.signalQuit
+                print " * Player Thread Running Signal Song End:"
                 self.__blIsPlaying = False
                 self.__blIsPaused = False
                 self.__blIsSongEnded = True
-                self.__volumeLevel = 0
-                self.__totalTime = 0.0
-                self.__positionTime = 0.0
-                self.__writeStandardInput('%s\n' % self.signalQuit)
-                print "Player Thread End Of Signal Song End"
+                self.__signal.volumeLevel = 0
+                self.__signal.totalTime = 0.0
+                self.__signal.positionTime = 0.0
+                self.__signal.quit_(self.__player)
+                print " * Player Thread End Of Signal Song End"
 
             # Signal to pause the song
             if command == self.__commandPause:
-                print "Player Thread Running Signal Pause: %s" % \
-                    self.signalPause
-                self.__writeStandardInput('%s\n' % self.signalPause)
-                print "Player Thread End Of Signal Pause"
+                print " * Player Thread Running Signal Pause"
+                self.__signal.pause(self.__player)
+                print " * Player Thread End Of Signal Pause"
 
             # Signal to unpause the song
             if command == self.__commandUnpause:
-                print "Player Thread Running Signal Unpause: %s" % \
-                    self.signalUnpause
-                self.__writeStandardInput('%s\n' % self.signalUnpause)
-                print "Player Thread End Of Signal Unpause"
+                print " * Player Thread Running Signal Unpause"
+                self.__signal.unpause(self.__player)
+                print " * Player Thread End Of Signal Unpause"
 
             # Signal to change the volume of the player
-            # TODO make player agnostic using a signal class.
             if command == self.__commandVolume: # set volume
-                print "Player Thread Running Signal Volume: %s" % \
-                    self.signalVolume
-                self.__writeStandardInput('%s %s 1\n' % (self.signalVolume, \
-                    self.__volumeLevel))
-                print "Player Thread End Of Signal Volume"
+                print " * Player Thread Running Signal Volume"
+                self.__signal.setVolume(self.__player)
+                print " * Player Thread End Of Signal Volume"
 
             # Signal to get the total time of the song.
-            # TODO make player agnostic using a signal class.
             if command == self.__commandTotalTime: # get total time
-                print "Player Thread Running Signal TotalTime: %s" % \
-                    self.signalTotalTime
-                self.__writeStandardInput('%s\n' % self.signalTotalTime)
-                line = self.__readStandardOut()
-                while line is not "" and not "ANS_LENGTH" in line:
-                    line = self.__readStandardOut()
-                if line:
-                    self.__totalTime = float( \
-                        line.split("=")[1].replace("\n", ""))
-                print "Player Thread End Of Signal TotalTime"
+                print " * Player Thread Running Signal TotalTime"
+                self.__signal.playerTotalTime(self.__player)
+                print " * Player Thread End Of Signal TotalTime"
 
             # Signal to get the current position of the song.
-            # TODO make player agnostic using a signal class.
             if command == self.__commandPositionTime:
                 # Check is placed here to ensure we can correctly determine
                 #   the end of a song.
                 if not self.__blIsPaused:
-                    print "Player Thread Running Signal PositionTime: %s" % \
-                        self.signalPositionTime
-                    self.__writeStandardInput('%s\n' % \
-                        self.signalPositionTime)
-                    line = self.__readStandardOut()
-                    while line is not "" and not \
-                            "ANS_TIME_POSITION" in line:
-                        line = self.__readStandardOut()
-                    if line:
-                        self.__positionTime = float( \
-                            line.split("=")[1].replace("\n", ""))
-                    print "Player Thread End Of Signal PositionTime"
+                    print " * Player Thread Running Signal PositionTime"
+                    self.__signal.playerPositionTime(self.__player)
+                    print " * Player Thread End Of Signal PositionTime"
 
             # Signal to set the current position of the song.
-            # TODO make player agnostic using a signal class.
             if command == self.__commandSetPositionTime:
-                print "Player Thread Running Signal SetPostionTime %s" % \
-                    self.signalSetPositionTime
-                self.__writeStandardInput('%s %s 2\n' % \
-                    (self.signalSetPositionTime, self.__positionTime))
-                print "Player Thread End Of Signal SetPostionTime"
-            print "Player Thread Finished Processing Command:", command
+                print " * Player Thread Running Signal SetPostionTime"
+                self.__signal.setPlayerPositionTime(self.__player)
+                print " * Player Thread End Of Signal SetPostionTime"
+            print "Player Thread Finished Command:", command
             self.__cndtnRunCommand.release()
         print "Player Thread Ended"
 
@@ -321,68 +240,6 @@ class PlayerThread(Thread):
             self.__commandQueue.put(command, True)
         self.__lckCommandQueue.release()
 
-    def __writeStandardInput(self, signal):
-        """ Send a signal to the player.
-
-         string signal: is the command to issue to the player on it's
-           standard input.
-        """
-        self.__lckWriteStandardInput.acquire()
-        if self.__ppnPlayer.poll() is None:
-            try:
-                self.__ppnPlayer.stdin.write(signal)
-            except IOError, message:
-                print message
-            else:
-                print "Player Thread Sending Signal:%s." % \
-                    signal.replace("\n", "")
-            finally:
-                self.__lckWriteStandardInput.release()
-        else:
-            self.__lckWriteStandardInput.release()
-
-    def __readStandardOut(self):
-        """ Read a line from the standard out.
-
-         return string: the first line in standard out.
-        """
-        line = ""
-        self.__lckReadStandardOut.acquire()
-        if self.__ppnPlayer.poll() is None:
-            try:
-                line = self.__ppnPlayer.stdout.readline(-1)
-            except IOError, message:
-                print message
-            else:
-                print "Player Thread Standard Out: %s" % \
-                    line.replace("\n", "")
-            finally:
-                self.__lckReadStandardOut.release()
-        else:
-            self.__lckReadStandardOut.release()
-        return line
-
-    def __readStandardError(self):
-        """ Read a line from the standard error.
-
-         return string: the first line in standard error.
-        """
-        line = ""
-        self.__lckReadStandardError.acquire()
-        if self.__ppnPlayer.poll() is None:
-            try:
-                line = self.__ppnPlayer.stderr.readline(-1)
-            except IOError, message:
-                print message
-            else:
-                print "Player Thread Standard Error: %s" % \
-                    line.replace("\n", "")
-            finally:
-                self.__lckReadStandardError.release()
-        else:
-            self.__lckReadStandardError.release()
-        return line
-
     def isRunning(self):
         """ Indicates if the player is in a running state. """
         return self.__blIsRunning
@@ -409,6 +266,7 @@ class PlayerThread(Thread):
 
     def quitRunning(self):
         """ Issues the command to quit running. """
+        print "PlayerThread.quitRunning(self)", self
         self.__pushCommand(self.__commandQuitRunning)
         self.__cndtnRunCommand.acquire()
         self.__cndtnRunCommand.notify()
@@ -416,6 +274,7 @@ class PlayerThread(Thread):
 
     def fullScreen(self):
         """ Issues the command to display the current song full screen. """
+        print "PlayerThread.fullScreen(self)", self
         self.__pushCommand(self.__commandFullScreen)
         self.__cndtnRunCommand.acquire()
         self.__cndtnRunCommand.notify()
@@ -429,32 +288,31 @@ class PlayerThread(Thread):
          return boolean: True if commands are placed in the queue, False
            if a song is already loaded or if the file cannot be found.
         """
-        # TODO check to ensure the file exists.
+        print "PlayerThread.play(self, filePath, volume)", self, filePath, \
+            volume
         if not filePath:
             print "PlayerThread.play(): Empty filePath"
             return False
         elif not os.access(filePath, os.F_OK):
-            print "PlayerThread.play(): File not found: %s " % \
-                self.__songFilePath
+            print "PlayerThread.play(): File not found: %s " % filePath
             return False
         elif not os.access(filePath, os.R_OK):
-            print "PlayerThread.play(): File doesn't have read access: %s " % \
-                self.__songFilePath
+            print "PlayerThread.play(): missing read access: %s " % filePath
             return False
         elif not self.__blIsPlaying and not self.__blIsPaused:
-            self.__songFilePath = " \"" + filePath + "\""
+            self.__signal.songFilePath = " \"" + filePath + "\""
             self.__pushCommand(self.__commandPlay)
             self.__cndtnRunCommand.acquire()
             self.__cndtnRunCommand.notify()
             self.__cndtnRunCommand.release()
             return self.setVolumeLevel(volume, noCheckPlaying=True)
         else:
-            print "PlayerThread.play(): Already playing: %s " % \
-                self.__songFilePath
+            print "PlayerThread.play(): Already playing a song."
             return False
 
     def stop(self):
         """ Issues the command to stop. """
+        print "PlayerThread.stop(self)", self
         if not self.__blIsSongEnded and (self.__blIsPlaying or \
                 self.__blIsPaused):
             self.__pushCommand(self.__commandStop)
@@ -464,6 +322,7 @@ class PlayerThread(Thread):
 
     def pause(self):
         """ Issues the command to pause """
+        print "PlayerThread.pause(self)", self
         if self.__blIsPlaying:
             self.__pushCommand(self.__commandPause)
             self.__blIsPlaying = False
@@ -474,6 +333,7 @@ class PlayerThread(Thread):
 
     def unpause(self):
         """ Issues the command to un-pause """
+        print "PlayerThread.unpause(self)", self
         if self.__blIsPaused:
             self.__pushCommand(self.__commandUnpause)
             self.__blIsPlaying = True
@@ -491,8 +351,10 @@ class PlayerThread(Thread):
          return boolean: True if the volume command is placed in the queue,
            False if we are not in a playing state.
         """
+        print "PlayerThread.setVolumeLevel(self, volume, noCheckPlaying)", \
+            self, volume, noCheckPlaying
         if self.__blIsPlaying or noCheckPlaying:
-            self.__volumeLevel = volume
+            self.__signal.volumeLevel = volume
             self.__pushCommand(self.__commandVolume)
             self.__cndtnRunCommand.acquire()
             self.__cndtnRunCommand.notify()
@@ -503,7 +365,7 @@ class PlayerThread(Thread):
 
     def volumeLevel(self):
         """ Gives the current volume level percentage. """
-        return self.__volumeLevel
+        return self.__signal.volumeLevel
 
     def positionInSong(self):
         """ Give the current position in the playing song.
@@ -516,7 +378,7 @@ class PlayerThread(Thread):
         self.__cndtnRunCommand.acquire()
         self.__cndtnRunCommand.notify()
         self.__cndtnRunCommand.release()
-        return self.__positionTime
+        return self.__signal.positionTime
 
     def setPlayPosition(self, seconds):
         """ Issues the command to set the current playing position.
@@ -524,8 +386,9 @@ class PlayerThread(Thread):
          float seconds: is the number of seconds to play from.
          return boolean: True if we are in a playing state, False else-wise.
         """
+        print "PlayerThread.setPlayPosition(self, seconds)", self, seconds
         if self.__blIsPlaying:
-            self.__positionTime = seconds
+            self.__signal.positionTime = seconds
             self.__pushCommand(self.__commandSetPositionTime)
             self.__cndtnRunCommand.acquire()
             self.__cndtnRunCommand.notify()
@@ -546,4 +409,4 @@ class PlayerThread(Thread):
             self.__cndtnRunCommand.acquire()
             self.__cndtnRunCommand.notify()
             self.__cndtnRunCommand.release()
-        return self.__totalTime
+        return self.__signal.totalTime
