@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 #******************************************************************************
-#**** Copyright (C) 2009  John Schneiderman <JohnMS@member.fsf.org>        ****
+#**** Copyright (C) 2009, 2010                                             ****
+#****   John Schneiderman <JohnMS@member.fsf.org>                          ****
 #****                                                                      ****
 #**** This program is free software: you can redistribute it and/or modify ****
 #**** it under the terms of the GNU General Public License as published by ****
@@ -55,7 +56,7 @@ class PlayListWindow(wx.Panel):
     # Used to indicate to remove the selected song from the play-list.
     __ID_REMOVE = wx.NewId()
 
-    def __init__(self, parent, id=wx.NewId()):
+    def __init__(self, parent, iconPath, id=wx.NewId()):
         """ Default constructor
 
          wx.Window parent: is the parent window.
@@ -64,28 +65,33 @@ class PlayListWindow(wx.Panel):
         wx.Panel.__init__(self, parent, id)
         random.seed()
 
-        self.__createControls()
+        self.__createControls(iconPath)
         self.__bindEvents()
         self.__doLayout()
 
-    def __createControls(self):
+    def __createControls(self, iconPath):
         """ Create the controls for the play-list window. """
         self.__lstBxPlayList = wx.ListBox(self, style=wx.LB_SINGLE)
 
         # Create Play List Button Movements
-        self.__bttnMoveTop = wx.Button(self, self.__ID_TOP, "TOP", \
+        self.__btmpBttnMoveTop = wx.BitmapButton(self, self.__ID_TOP, \
+            wx.Bitmap(iconPath + '/top.png'), \
             size=wx.Size(self.__BUTTON_MOVEMENT_WIDTH, \
             self.__BUTTON_MOVEMENT_HEIGHT))
-        self.__bttnMoveUp = wx.Button(self, self.__ID_UP, "UP", \
+        self.__btmpBttnMoveUp = wx.BitmapButton(self, self.__ID_UP, \
+            wx.Bitmap(iconPath + '/up.png'), \
             size=wx.Size(self.__BUTTON_MOVEMENT_WIDTH, \
             self.__BUTTON_MOVEMENT_HEIGHT))
-        self.__bttnMoveDown = wx.Button(self, self.__ID_DOWN, "DWN", \
+        self.__btmpBttnMoveDown = wx.BitmapButton(self, self.__ID_DOWN, \
+            wx.Bitmap(iconPath + '/down.png'), \
             size=wx.Size(self.__BUTTON_MOVEMENT_WIDTH, \
             self.__BUTTON_MOVEMENT_HEIGHT))
-        self.__bttnMoveBottom = wx.Button(self, self.__ID_BOTTOM, "BTM", \
+        self.__btmpBttnMoveBottom = wx.BitmapButton(self, self.__ID_BOTTOM, \
+            wx.Bitmap(iconPath + '/bottom.png'), \
             size=wx.Size(self.__BUTTON_MOVEMENT_WIDTH, \
             self.__BUTTON_MOVEMENT_HEIGHT))
-        self.__bttnRemove = wx.Button(self, self.__ID_REMOVE, "REM", \
+        self.__btmpBttnMoveRemove = wx.BitmapButton(self, self.__ID_REMOVE, \
+            wx.Bitmap(iconPath + '/remove.png'), \
             size=wx.Size(self.__BUTTON_MOVEMENT_WIDTH, \
             self.__BUTTON_MOVEMENT_HEIGHT))
 
@@ -112,15 +118,15 @@ class PlayListWindow(wx.Panel):
 
         # Play List Button Layout
         self.__bxSzrPlayListButtons = wx.BoxSizer(wx.VERTICAL)
-        self.__bxSzrPlayListButtons.Add(self.__bttnMoveTop, 1, wx.ALL, 3)
+        self.__bxSzrPlayListButtons.Add(self.__btmpBttnMoveTop, 1, wx.ALL, 3)
         self.__bxSzrPlayListButtons.AddSpacer(1)
-        self.__bxSzrPlayListButtons.Add(self.__bttnMoveUp, 0, wx.ALL, 3)
+        self.__bxSzrPlayListButtons.Add(self.__btmpBttnMoveUp, 0, wx.ALL, 3)
         self.__bxSzrPlayListButtons.AddSpacer(1)
-        self.__bxSzrPlayListButtons.Add(self.__bttnMoveDown, 0, wx.ALL, 3)
+        self.__bxSzrPlayListButtons.Add(self.__btmpBttnMoveDown, 0, wx.ALL, 3)
         self.__bxSzrPlayListButtons.AddSpacer(1)
-        self.__bxSzrPlayListButtons.Add(self.__bttnMoveBottom, 0, wx.ALL, 3)
+        self.__bxSzrPlayListButtons.Add(self.__btmpBttnMoveBottom, 0, wx.ALL, 3)
         self.__bxSzrPlayListButtons.AddSpacer(10)
-        self.__bxSzrPlayListButtons.Add(self.__bttnRemove, 0, wx.ALL, 3)
+        self.__bxSzrPlayListButtons.Add(self.__btmpBttnMoveRemove, 0, wx.ALL, 3)
 
         # Create Interface
         self.__bxSzrInterface = wx.BoxSizer(wx.HORIZONTAL)
